@@ -1,4 +1,4 @@
-// Copyright (C) 2001, 2002 Federico Montesino Pouzols <fedemp@altern.org>.
+// Copyright (C) 2001-2005 Federico Montesino Pouzols <fedemp@altern.org>.
 // 
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -14,35 +14,34 @@
 // along with this program; if not, write to the Free Software 
 // Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 // 
-// As a special exception to the GNU General Public License, permission is 
-// granted for additional uses of the text contained in its release 
-// of ccRTP.
-// 
-// The exception is that, if you link the ccRTP library with other
-// files to produce an executable, this does not by itself cause the
-// resulting executable to be covered by the GNU General Public License.
-// Your use of that executable is in no way restricted on account of
-// linking the ccRTP library code into it.
-// 
-// This exception does not however invalidate any other reasons why
-// the executable file might be covered by the GNU General Public License.
-// 
-// This exception applies only to the code released under the 
-// name ccRTP.  If you copy code from other releases into a copy of
+// As a special exception, you may use this file as part of a free software
+// library without restriction.  Specifically, if other files instantiate
+// templates or use macros or inline functions from this file, or you compile
+// this file and link it with other files to produce an executable, this
+// file does not by itself cause the resulting executable to be covered by
+// the GNU General Public License.  This exception does not however    
+// invalidate any other reasons why the executable file might be covered by
+// the GNU General Public License.    
+//
+// This exception applies only to the code released under the name GNU
+// ccRTP.  If you copy code from other releases into a copy of GNU
 // ccRTP, as the General Public License permits, the exception does
 // not apply to the code that you add in this way.  To avoid misleading
 // anyone as to the status of such modified files, you must delete
 // this exception notice from them.
-// 
-// If you write modifications of your own for ccRTP, it is your choice
+//
+// If you write modifications of your own for GNU ccRTP, it is your choice
 // whether to permit this exception to apply to your modifications.
-// If you do not wish that, delete this exception notice.  
+// If you do not wish that, delete this exception notice.
+//
 
 #ifndef	CCXX_RTP_BASE_H_
 #define CCXX_RTP_BASE_H_
 
+#ifndef	CCXX_SOCKET_H_
 #include <cc++/config.h>
 #include <cc++/socket.h>
+#endif
 
 #ifdef CCXX_NAMESPACES
 namespace ost {
@@ -71,7 +70,7 @@ typedef uint32 nanotimeout_t;
  * @param to time interval, in microseconds.
  * @return the same time interval, as a timeval value.
  **/
-CCXX_EXPORT(timeval)
+__EXPORT timeval 
 microtimeout2Timeval(microtimeout_t to);
 
 /**
@@ -106,13 +105,15 @@ const tpport_t DefaultRTPDataPort = 5004;
 /// registered default RTCP transport port
 const tpport_t DefaultRTCPPort = 5005;
 
-#ifdef WIN32
-CCXX_EXPORT(int)
+#ifndef	HAVE_GETTIMEOFDAY
+#ifdef	WIN32
+__EXPORT int
 gettimeofday(struct timeval *tv_, void *tz_);
 #endif
+#endif
 
 #ifdef  CCXX_NAMESPACES
-};
+}
 #endif
 
 #endif  // ndef CCXX_RTP_BASE_H_
